@@ -16,9 +16,9 @@
 import logging
 import os
 import testtools
+from unittest import mock
 
 import fixtures
-import mock
 from oslo_concurrency import lockutils
 from oslo_config import fixture as config_fixture
 from oslo_utils import strutils
@@ -61,6 +61,11 @@ class TestCase(testtools.TestCase):
             self.useFixture(fixtures.LoggerFixture(nuke_handlers=False,
                                                    format=log_format,
                                                    level=level))
+        # Protect against any case where someone doesn't remember to patch a
+        # retry decorated call
+        patcher = mock.patch('os_brick.utils._time_sleep')
+        patcher.start()
+        self.addCleanup(patcher.stop)
 
         # At runtime this would be set by the library user: Cinder, Nova, etc.
         self.useFixture(fixtures.NestedTempfile())
