@@ -12,9 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import ddt
-import mock
 import os
+from unittest import mock
+
+import ddt
 import six
 
 from os_brick import exception
@@ -510,7 +511,7 @@ class FibreChannelConnectorTestCase(test_connector.ConnectorTestCase):
         mock_isdir.return_value = False
         expected = []
         actual = self.connector.get_all_available_volumes()
-        self.assertItemsEqual(expected, actual)
+        self.assertCountEqual(expected, actual)
 
     @mock.patch('eventlet.greenthread.sleep', mock.Mock())
     @mock.patch.object(linuxscsi.LinuxSCSI, 'find_multipath_device')
