@@ -15,10 +15,9 @@
 import os
 import os.path
 import textwrap
-import time
+from unittest import mock
 
 import ddt
-import mock
 from oslo_concurrency import processutils as putils
 from oslo_log import log as logging
 
@@ -103,7 +102,7 @@ class LinuxSCSITestCase(base.TestCase):
         expected_commands = [('tee -a /sys/block/sdc/device/delete')]
         self.assertEqual(expected_commands, self.cmds)
 
-    @mock.patch('time.sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     @mock.patch('os.path.exists', return_value=True)
     def test_wait_for_volumes_removal_failure(self, exists_mock, sleep_mock):
         retries = 61
@@ -114,7 +113,7 @@ class LinuxSCSITestCase(base.TestCase):
                                       for name in names] * retries)
         self.assertEqual(retries - 1, sleep_mock.call_count)
 
-    @mock.patch('time.sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     @mock.patch('os.path.exists', side_effect=(True, True, False, False))
     def test_wait_for_volumes_removal_retry(self, exists_mock, sleep_mock):
         names = ('sda', 'sdb')
@@ -195,7 +194,7 @@ class LinuxSCSITestCase(base.TestCase):
         expected_path = '/dev/disk/by-id/dm-uuid-mpath-%s' % fake_wwn
         self.assertEqual(expected_path, found_path)
 
-    @mock.patch('time.sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     @mock.patch.object(os.path, 'exists')
     def test_find_multipath_device_path_mapper(self, exists_mock, sleep_mock):
         # the wait loop tries 3 times before it gives up
@@ -211,14 +210,14 @@ class LinuxSCSITestCase(base.TestCase):
         self.assertTrue(sleep_mock.called)
 
     @mock.patch.object(os.path, 'exists', return_value=False)
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_find_multipath_device_path_fail(self, exists_mock, sleep_mock):
         fake_wwn = '1234567890'
         found_path = self.linuxscsi.find_multipath_device_path(fake_wwn)
         self.assertIsNone(found_path)
 
     @mock.patch.object(os.path, 'exists', return_value=False)
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_wait_for_path_not_found(self, exists_mock, sleep_mock):
         path = "/dev/disk/by-id/dm-uuid-mpath-%s" % '1234567890'
         self.assertRaisesRegex(exception.VolumeDeviceNotFound,
@@ -570,7 +569,7 @@ class LinuxSCSITestCase(base.TestCase):
         self.assertEqual("1", info['devices'][1]['id'])
         self.assertEqual("9", info['devices'][1]['lun'])
 
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_wait_for_rw(self, mock_sleep):
         lsblk_output = """3624a93709a738ed78583fd1200143029 (dm-2)  0
 sdb                                       0
@@ -612,7 +611,7 @@ loop0                                     0"""
         self.linuxscsi.wait_for_rw(wwn, path)
         self.assertFalse(mock_sleep.called)
 
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_wait_for_rw_needs_retry(self, mock_sleep):
         lsblk_ro_output = """3624a93709a738ed78583fd1200143029 (dm-2)  0
 sdb                                       0
@@ -682,7 +681,7 @@ loop0                                     0"""
         self.linuxscsi.wait_for_rw(wwn, path)
         self.assertEqual(1, mock_sleep.call_count)
 
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_wait_for_rw_always_readonly(self, mock_sleep):
         lsblk_output = """3624a93709a738ed78583fd1200143029 (dm-2)  0
 sdb                                       0
@@ -913,30 +912,67 @@ loop0                                     0"""
         self.assertEqual(expected, result)
 
     @mock.patch('os_brick.privileged.rootwrap.execute', return_value=('', ''))
-    def test_is_multipath_running_default_executor(self, mock_exec):
+    def test_is_multipath_running(self, mock_exec):
         res = linuxscsi.LinuxSCSI.is_multipath_running(False, None, mock_exec)
         self.assertTrue(res)
         mock_exec.assert_called_once_with(
             'multipathd', 'show', 'status', run_as_root=True, root_helper=None)
 
+    @mock.patch.object(linuxscsi, 'LOG')
     @mock.patch('os_brick.privileged.rootwrap.execute')
-    def test_is_multipath_running_failure_exit_code_0(self, mock_exec):
+    def test_is_multipath_running_failure(
+        self, mock_exec, mock_log
+    ):
+        mock_exec.side_effect = putils.ProcessExecutionError()
+        self.assertRaises(putils.ProcessExecutionError,
+                          linuxscsi.LinuxSCSI.is_multipath_running,
+                          True, None, mock_exec)
+        mock_log.error.assert_called_once()
+
+    @mock.patch.object(linuxscsi, 'LOG')
+    @mock.patch('os_brick.privileged.rootwrap.execute')
+    def test_is_multipath_running_failure_exit_code_0(
+        self, mock_exec, mock_log
+    ):
         mock_exec.return_value = ('error receiving packet', '')
         self.assertRaises(putils.ProcessExecutionError,
                           linuxscsi.LinuxSCSI.is_multipath_running,
                           True, None, mock_exec)
         mock_exec.assert_called_once_with(
             'multipathd', 'show', 'status', run_as_root=True, root_helper=None)
+        mock_log.error.assert_called_once()
+
+    @mock.patch.object(linuxscsi, 'LOG')
+    @mock.patch('os_brick.privileged.rootwrap.execute')
+    def test_is_multipath_running_failure_not_enforcing_multipath(
+        self, mock_exec, mock_log
+    ):
+        mock_exec.side_effect = putils.ProcessExecutionError()
+        res = linuxscsi.LinuxSCSI.is_multipath_running(False, None, mock_exec)
+        mock_exec.assert_called_once_with(
+            'multipathd', 'show', 'status', run_as_root=True, root_helper=None)
+        self.assertFalse(res)
+        mock_log.error.assert_not_called()
+
+    @mock.patch.object(linuxscsi, 'LOG')
+    @mock.patch('os_brick.privileged.rootwrap.execute')
+    def test_is_multipath_running_failure_not_enforcing_exit_code_0(
+        self, mock_exec, mock_log
+    ):
+        mock_exec.return_value = ('error receiving packet', '')
+        res = linuxscsi.LinuxSCSI.is_multipath_running(False, None, mock_exec)
+        mock_exec.assert_called_once_with(
+            'multipathd', 'show', 'status', run_as_root=True, root_helper=None)
+        self.assertFalse(res)
+        mock_log.error.assert_not_called()
 
     def test_get_device_info(self):
-        ret = "/dev/sg0 scsi1 channel=1 id=0 lun=0 [em]\n"
+        ret = "[1:1:0:0] disk Vendor Array 0100 /dev/adevice\n"
         with mock.patch.object(self.linuxscsi, '_execute') as exec_mock:
             exec_mock.return_value = (ret, "")
             info = self.linuxscsi.get_device_info('/dev/adevice')
 
-            exec_mock.assert_called_once_with('sg_scan', '/dev/adevice',
-                                              root_helper=None,
-                                              run_as_root=True)
+            exec_mock.assert_called_once_with('lsscsi')
             self.assertEqual(info, {'channel': '1',
                                     'device': '/dev/adevice',
                                     'host': '1',
